# Basic Tenants
* Ease of Use > Accuracy > Speed (with speed more important with 'fast' selections)
* Availability of models which share information among series
* All models should be probabilistic (upper/lower forecasts)
* New transformations should be applicable to many datasets and models
* New models need only be sometimes applicable
* Fault tolerance: it is perfectly acceptable for model parameters to fail on some datasets, the higher level API will pass over and use others.
* Missing data tolerance: large chunks of data can be missing and model will still produce reasonable results (although lower quality than if data is available)

## Assumptions on Data
* Series will largely be consistent in period, or at least up-sampled to regular intervals
* The most recent data will generally be the most important
* Forecasts are desired for the future immediately following the most recent data.

# Latest :space_invader: :space_invader: :space_invader:
* plot_horizontal_per_generation and horizontal_per_generation added
* model_list now accepts a dictionary of probabilities, however this only affects new Random Templates
* :seedling: improved the genetic algorithm for new model generation
* minor improvement to generate_score_per_series for handling very small ~e-20 errors
* added PytorchForecasting to available models
* Johansen Cointegration transformer
* BTCD transformer
* Johansen and BTCD as Regression features
* fixed bug in plot_horizontal()
* added ARCH to available models
* changed the sklearn models used by UnivariateRegression by default and returned to default model_list
* fixed a bug in KerasRNN

### New Model Checklist:
	* Add to ModelMonster in auto_model.py
	* add to appropriate model_lists: all, recombination_approved if so, no_shared if so
	* add to model table in extended_tutorial.md (most columns here have an equivalent model_list)
	* if model has regressors, make sure it meets Simulation Forecasting needs (method="regressor", fails on no regressor if "User")

## New Transformer Checklist:
	* Make sure that if it modifies the size (more/fewer columns or rows) it returns pd.DataFrame with proper index/columns
	* depth of recombination is?
	* add to "all" transformer_dict
	* add to no_params or external if so
	* add to shared_trans if so
	* oddities_list for those with forecast/original transform difference

## New Metric Checklist:
	* Create function in metrics.py
	* Add to mode base .evaluate()  (benchmark to make sure it is still fast)
	* Add to concat in TemplateWizard (if per_series metrics will be used)
	* Add to concat in TemplateEvalObject (if per_series metrics will be used)
	* Add to generate_score
	* Add to generate_score_per_series (if per_series metrics will be used)
	* Add to validation_aggregation
	* Update test_metrics results
